# -*- coding: utf-8 -*-
"""Define project metadata."""


__package_name__ = 'finder'
__description__ = ('Command line interface for searching a given pattern in '
                   'the given directory/file paths')
__url__ = 'https://github.com/bharadwajyarlagadda/finder'
__version__ = '1.0.1'
__author__ = 'Bharadwaj Yarlagadda'
__email__ = 'yarlagaddabharadwaj@gmail.com'
__license__ = 'MIT License'
